Learn R Programming

FAMetA (version 0.1.7)

fitSSE: Fit FA isotope distribution with non-linear regression and calculate the sum of squared estimate of errors.

Description

Fit FA isotope distribution with non-linear regression and calculate the sum of squared estimate of errors.

Usage

fitSSE(formula, startpars, datanls, control, limitPhi = 0.1)

Value

sum of squared estimate errors.

Arguments

formula

formula.

startpars

starting points for parameters to estimate.

datanls

data list.

control

nls control.

Author

M Isabel Alcoriza-Balaguer <maribel_alcoriza@iislafe.es>

References

Daniel Padfield and Granville Matheson (2020). nls.multstart: Robust Non-Linear Regression using AIC Scores. R package version 1.2.0. <https://CRAN.R-project.org/package=nls.multstart>